# heatmap
## Better heatmaps in Python

Python code and Jupyter notebook for an improved heatmap implementation using Matplotlib and Seaborn.

Similar to what you can easily get in Tableau using a Size parameter, here you can have square size as parameter depending on the field value.

Described in detail in this blog post: https://towardsdatascience.com/better-heatmaps-and-correlation-matrix-plots-in-python-41445d0f2bec

### Example of a correlation matrix

![Correlation matrix](https://cdn-images-1.medium.com/max/800/1*TlESRbDQshEcLyX1axiUoA.png)


### Example of a discrete joint distribution

![Discrete joint distribution](https://miro.medium.com/max/1400/1*D2K6pLDIE7i2a6HP0UAJhA.png)








